from enum import Enum
from toloka.client.primitives.base import BaseTolokaObject
from typing import (
    Any,
    Dict,
    List,
    Optional
)

class AdditionalLanguage(BaseTolokaObject):
    """Description for additional language in project

    Args:
        language: The language into which the translation is made. A string from ISO 639-1.
        public_name: Translation of the project field 'public_name' into the specified language.
        public_description: Translation of the project field 'public_description' into the specified language.
        public_instructions: Translation of the project field 'public_instructions' into the specified language.
    """

    class FieldTranslation(BaseTolokaObject):
        """Translation of one specific field

        Args:
            value: A string translated into the desired language.
            source: In creation you can pass only 'REQUESTER' right now.
        """

        class Source(Enum):
            """Possible values of sources

            In creation you can pass only 'REQUESTER' right now.
            """

            REQUESTER = 'REQUESTER'

        def __init__(self, *, value: Optional[str] = None, source: Optional[Source] = None) -> None:
            """Method generated by attrs for class AdditionalLanguage.FieldTranslation.
            """
            ...

        _unexpected: Optional[Dict[str, Any]]
        value: Optional[str]
        source: Optional[Source]

    def __init__(self, *, language: Optional[str] = None, public_name: Optional[FieldTranslation] = None, public_description: Optional[FieldTranslation] = None, public_instructions: Optional[FieldTranslation] = None) -> None:
        """Method generated by attrs for class AdditionalLanguage.
        """
        ...

    _unexpected: Optional[Dict[str, Any]]
    language: Optional[str]
    public_name: Optional[FieldTranslation]
    public_description: Optional[FieldTranslation]
    public_instructions: Optional[FieldTranslation]


class LocalizationConfig(BaseTolokaObject):
    """Translates the part of the project visible to the performers into different languages

    It is used to make it easier for performers from other countries who do not speak the necessary language to
    understand and perform tasks.

    Args:
        default_language: The source language used in the fields public_name, public_description, and public_instructions.
            Required parameter.
        additional_languages: List of translations into other languages. One element - one translation.
    """

    def __init__(self, *, default_language: Optional[str] = None, additional_languages: Optional[List[AdditionalLanguage]] = None) -> None:
        """Method generated by attrs for class LocalizationConfig.
        """
        ...

    _unexpected: Optional[Dict[str, Any]]
    default_language: Optional[str]
    additional_languages: Optional[List[AdditionalLanguage]]
