__all__ = [
    'WebhookSubscription',
]
from datetime import datetime
from enum import Enum
from toloka.client.primitives.base import BaseTolokaObject
from typing import (
    Any,
    Dict,
    Optional
)

class WebhookSubscription(BaseTolokaObject):
    """Webhook subscription to make a callback to the given address when some event happen.

    Attributes:
        webhook_url: The URL to which notifications will be sent.
        event_type: Event type.
        pool_id: ID of the pool for which the subscription was created.
        id: Pool ID. Read only field.
        created: When this pool was created. Read only field.
    """

    class EventType(Enum):
        """Webhook subscription event type:

        Attributes:
            POOL_CLOSED: The pool is closed.
            DYNAMIC_OVERLAP_COMPLETED: There is an aggregated estimate for dynamic overlap.
            ASSIGNMENT_CREATED: Task created.
            ASSIGNMENT_SUBMITTED: The task has been completed and is waiting for acceptance by the customer.
            ASSIGNMENT_SKIPPED: The task was taken to work, but the performer missed it and will not return to it.
            ASSIGNMENT_EXPIRED: The task was taken to work, but the performer did not have time to complete it in the allotted time or refused it before the end of the term.
            ASSIGNMENT_APPROVED: The task was performed by the performer and confirmed by the customer.
            ASSIGNMENT_REJECTED: The task was completed by the performer, but rejected by the customer.
        """

        POOL_CLOSED = 'POOL_CLOSED'
        DYNAMIC_OVERLAP_COMPLETED = 'DYNAMIC_OVERLAP_COMPLETED'
        ASSIGNMENT_CREATED = 'ASSIGNMENT_CREATED'
        ASSIGNMENT_SUBMITTED = 'ASSIGNMENT_SUBMITTED'
        ASSIGNMENT_SKIPPED = 'ASSIGNMENT_SKIPPED'
        ASSIGNMENT_EXPIRED = 'ASSIGNMENT_EXPIRED'
        ASSIGNMENT_APPROVED = 'ASSIGNMENT_APPROVED'
        ASSIGNMENT_REJECTED = 'ASSIGNMENT_REJECTED'

    def __init__(
        self,
        *,
        webhook_url: Optional[str] = None,
        event_type: Optional[EventType] = None,
        pool_id: Optional[str] = None,
        secret_key: Optional[str] = None,
        id: Optional[str] = None,
        created: Optional[datetime] = None
    ) -> None:
        """Method generated by attrs for class WebhookSubscription.
        """
        ...

    _unexpected: Optional[Dict[str, Any]]
    webhook_url: Optional[str]
    event_type: Optional[EventType]
    pool_id: Optional[str]
    secret_key: Optional[str]
    id: Optional[str]
    created: Optional[datetime]
